Hachi: XBee API
===============

.. image:: https://travis-ci.org/Diaoul/hachi.png?branch=master
    :target: https://travis-ci.org/Diaoul/hachi

Hachi is an `Apache2 Licensed <http://opensource.org/licenses/Apache-2.0>`_ Python library to interact with XBees.
